@@ -19,7 +19,7 @@
 
 ## save rules/itemsets as a graph for external programs 
 
-saveAsGraph <- function(x, file, type=NULL, format="graphml") {
+saveAsGraph <- function(x, file, type="items", format="graphml") {
     g <- plot(x, method="graph", control=list(plot=FALSE, type=type))
     igraph::write.graph(g, file, format=format)
 }
